@@ -38,6 +38,9 @@ logger = logging.getLogger(__name__)
 BLOSC_ID = 32001
 """Blosc filter ID"""
 
+BLOSC2_ID = 32026
+"""Blosc 2 filter ID"""
+
 BZIP2_ID = 307
 """Bzip2 filter ID"""
 
@@ -56,6 +59,9 @@ ZSTD_ID = 32015
 SZ_ID = 32017
 """SZ filter ID"""
 
+SZ3_ID = 32024
+"""SZ3 filter ID"""
+
 FCIDECOMP_ID = 32018
 """FCIDECOMP filter ID"""
 
@@ -177,6 +183,7 @@ class Blosc(_FilterRefClass):
         Compression level from 0 (no compression) to 9 (maximum compression).
         Default: 5.
     :param int shuffle: One of:
+
         - Blosc.NOSHUFFLE (0): No shuffle
         - Blosc.SHUFFLE (1): byte-wise shuffle (default)
         - Blosc.BITSHUFFLE (2): bit-wise shuffle
@@ -211,6 +218,68 @@ class Blosc(_FilterRefClass):
         self.filter_options = (0, 0, 0, 0, clevel, shuffle, compression)
 
 
+class Blosc2(_FilterRefClass):
+    """``h5py.Group.create_dataset``'s compression arguments for using blosc2 filter.
+
+    It can be passed as keyword arguments:
+
+    .. code-block:: python
+
+        f = h5py.File('test.h5', 'w')
+        f.create_dataset(
+            'blosc2_byte_shuffle_blosclz',
+            data=numpy.arange(100),
+            **hdf5plugin.Blosc2(cname='blosclz', clevel=9, filters=hdf5plugin.Blosc2.SHUFFLE))
+        f.close()
+
+    :param str cname:
+        `blosclz` (default), `lz4`, `lz4hc`, `zlib`, `zstd`
+    :param int clevel:
+        Compression level from 0 (no compression) to 9 (maximum compression).
+        Default: 5.
+    :param int filters: One of:
+
+        - Blosc2.NOFILTER (0): No pre-compression filter
+        - Blosc2.SHUFFLE (1): Byte-wise shuffle (default)
+        - Blosc2.BITSHUFFLE (2): Bit-wise shuffle
+        - Blosc2.DELTA (3): Stores diff'ed blocks
+        - Blosc2.TRUNC_PREC (4): Zeroes the least significant bits of the mantissa
+    """
+
+    NOFILTER = 0
+    """Flag to disable pre-compression filter"""
+
+    SHUFFLE = 1
+    """Flag to enable byte-wise shuffle pre-compression filter"""
+
+    BITSHUFFLE = 2
+    """Flag to enable bit-wise shuffle pre-compression filter"""
+
+    DELTA = 3
+    """Flag to store blocks inside a chunk diff'ed with respect to first block in the chunk"""
+
+    TRUNC_PREC = 4
+    """Flag to zeroes the least significant bits of the mantissa of float32 and float64 types"""
+
+    filter_id = BLOSC2_ID
+    filter_name = "blosc2"
+
+    __COMPRESSIONS = {
+        'blosclz': 0,
+        'lz4': 1,
+        'lz4hc': 2,
+        'zlib': 4,
+        'zstd': 5,
+    }
+
+    def __init__(self, cname='blosclz', clevel=5, filters=SHUFFLE):
+        compression = self.__COMPRESSIONS[cname]
+        clevel = int(clevel)
+        assert 0 <= clevel <= 9
+        assert filters in (self.NOFILTER, self.SHUFFLE, self.BITSHUFFLE, self.DELTA, self.TRUNC_PREC)
+        self.filter_options = (0, 0, 0, 0, clevel, filters, compression)
+
+
 class BZip2(_FilterRefClass):
     """``h5py.Group.create_dataset``'s compression arguments for using BZip2 filter.
 
@@ -416,7 +485,6 @@ class Zfp(_FilterRefClass):
 class SZ(_FilterRefClass):
     """``h5py.Group.create_dataset``'s compression arguments for using SZ filter.
 
-    For more details about the compressor `SZ <https://szcompressor.org/>`_.
     It can be passed as keyword arguments:
 
     .. code-block:: python
@@ -438,7 +506,7 @@ class SZ(_FilterRefClass):
           f.create_dataset(
               'sz_absolute',
               data=numpy.random.random(100),
-              **hdf5plugin.Zfp(absolute=0.1))
+              **hdf5plugin.SZ(absolute=0.1))
 
     - **Relative** mode: To use, set the ``relative`` argument.
       It ensures that the resulting values will be within the provided relative tolerance.
@@ -461,6 +529,7 @@ class SZ(_FilterRefClass):
               data=numpy.random.random(100),
               **hdf5plugin.SZ(pointwise_relative=0.01))
 
+    For more details about the compressor `SZ <https://szcompressor.org/>`_.
     """
     filter_name = "sz"
     filter_id = SZ_ID
@@ -500,6 +569,74 @@ class SZ(_FilterRefClass):
         return high, low
 
 
+class SZ3(_FilterRefClass):
+    """``h5py.Group.create_dataset``'s compression arguments for using SZ3 filter.
+
+    It can be passed as keyword arguments:
+
+    - **Absolute** mode: To use, set the ``absolute`` argument.
+      It ensures that the resulting values will be within the provided absolute tolerance.
+
+      .. code-block:: python
+
+          f.create_dataset(
+              'sz3_absolute',
+              data=numpy.random.random(100),
+              **hdf5plugin.SZ3(absolute=0.1))
+
+    For more details about the compressor, see `SZ3 <https://szcompressor.org/>`_.
+
+    .. warning::
+
+       Backward compatibility is currently not guaranteed:
+       See `this discussion <https://github.com/szcompressor/SZ3/issues/50#issuecomment-1901170917>`_.
+    """
+    filter_name = "sz3"
+    filter_id = SZ3_ID
+
+    def __init__(self, absolute=None, relative=None, norm2=None, peak_signal_to_noise_ratio=None):
+        n_nones = (absolute, relative, norm2, peak_signal_to_noise_ratio).count(None)
+        if n_nones < 3:
+            raise TypeError("hdf5plugin.SZ3() takes at most one not None argument")
+        elif n_nones == 4:
+            absolute = 0.0001
+            logger.warning(f"Defaulting to absolute={absolute}. This default might not be kept in future releases")
+
+        # Get SZ3 encoding options: range [0, 5]
+        if absolute is not None:
+            sz_mode = 0
+        elif relative is not None:
+            sz_mode = 1
+        elif norm2 is not None:
+            sz_mode = 2
+        elif peak_signal_to_noise_ratio is not None:
+            sz_mode = 3
+        if sz_mode not in [0, 2]:
+            logger.warning("Only absolute and norm2 modes properly tested")
+
+        compression_opts = (
+            sz_mode,
+            *self.__pack_float64(absolute or 0.),
+            *self.__pack_float64(relative or 0.),
+            *self.__pack_float64(norm2 or 0.),
+            *self.__pack_float64(peak_signal_to_noise_ratio or 0.),
+        )
+        logger.info(f"SZ3 mode {sz_mode} used.")
+        logger.info(f"filter options {compression_opts}")
+        # 9 values needed
+        if len(compression_opts) != 9:
+            raise IndexError("Invalid number of arguments")
+
+        self.filter_options = compression_opts
+
+    @staticmethod
+    def __pack_float64(error: float) -> tuple:
+        packed = struct.pack('>d', error)  # Pack as big-endian IEEE 754 double
+        high = struct.unpack('>I', packed[0:4])[0]  # Unpack most-significant bits as unsigned int
+        low = struct.unpack('>I', packed[4:8])[0]  # Unpack least-significant bits as unsigned int
+        return high, low
+
+
 class Zstd(_FilterRefClass):
     """``h5py.Group.create_dataset``'s compression arguments for using FciDecomp filter.
 
@@ -534,7 +671,7 @@ class Zstd(_FilterRefClass):
         self.filter_options = (clevel,)
 
 
-FILTER_CLASSES = Bitshuffle, Blosc, BZip2, FciDecomp, LZ4, SZ, Zfp, Zstd
+FILTER_CLASSES = Bitshuffle, Blosc, Blosc2, BZip2, FciDecomp, LZ4, SZ, SZ3, Zfp, Zstd
 
 
 FILTERS = dict((cls.filter_name, cls.filter_id) for cls in FILTER_CLASSES)
